[ofw] patch: "I before E except after C"

Tzachi Dar tzachid at mellanox.co.il
Sun Dec 21 02:33:52 PST 2008


Index: Q:/projinf4/trunk/tools/perftests/user/send_bw/send_bw.c
===================================================================
--- Q:/projinf4/trunk/tools/perftests/user/send_bw/send_bw.c (revision
3654)
+++ Q:/projinf4/trunk/tools/perftests/user/send_bw/send_bw.c (revision
3655)
@@ -426,11 +426,11 @@
 
  
  
- /* post recieve max msg size*/
+ /* post receive max msg size*/
  {
   int i;
   ib_recv_wr_t      *bad_wr_recv;
-  //recieve
+  //receive
   ctx->rwr.wr_id      = PINGPONG_RECV_WRID;
   ctx->rwr.ds_array = &ctx->recv_list;
   ctx->rwr.num_ds = 1;
@@ -609,7 +609,7 @@
   * BW since we are running with loop on the send side
   * while we should run on the receive side or enable retry in SW
   * Since the sender may be faster than the reciver than although
-  * we had posted recieve it is not enough and might end this will
+  * we had posted receive it is not enough and might end this will
   * result in deadlock of test since both sides are stuck on poll cq
   * In this test i do not solve this for the general test ,need to
write
   * separate test for UC/UD but in case the tx_depth is ~1/3 from the
@@ -793,7 +793,7 @@
    p_wc_done = NULL;
    p_wc_free->p_next = NULL;
    
-   /*Server is polling on recieve first */
+   /*Server is polling on receive first */
    if (user_param->use_event) {
     cl_status_t cl_status;
 
@@ -840,7 +840,7 @@
     }
    } while (ib_status == IB_SUCCESS);
    if (ib_status != IB_NOT_FOUND) {
-    fprintf(stderr, "Poll Recieve CQ failed %d\n", ib_status);
+    fprintf(stderr, "Poll Receive CQ failed %d\n", ib_status);
     return 12;
    }
 
Index: Q:/projinf4/trunk/tools/perftests/user/write_bw/write_bw.c
===================================================================
--- Q:/projinf4/trunk/tools/perftests/user/write_bw/write_bw.c (revision
3654)
+++ Q:/projinf4/trunk/tools/perftests/user/write_bw/write_bw.c (revision
3655)
@@ -630,7 +630,7 @@
    } while (ib_status == IB_SUCCESS);
 
    if (ib_status != IB_NOT_FOUND) {
-    fprintf(stderr, "Poll Recieve CQ failed %d\n", ib_status);
+    fprintf(stderr, "Poll Receive CQ failed %d\n", ib_status);
     return 12;
    }
 
Index: Q:/projinf4/trunk/tools/perftests/user/send_lat/send_lat.c
===================================================================
--- Q:/projinf4/trunk/tools/perftests/user/send_lat/send_lat.c (revision
3654)
+++ Q:/projinf4/trunk/tools/perftests/user/send_lat/send_lat.c (revision
3655)
@@ -324,7 +324,7 @@
  ctx->wr.wr_type = WR_SEND;
  ctx->wr.p_next       = NULL; 
 
- //recieve
+ //receive
  ctx->rwr.wr_id      = PINGPONG_RECV_WRID;
  ctx->rwr.ds_array = &ctx->recv_list;
  ctx->rwr.num_ds = 1;
@@ -417,11 +417,11 @@
 
  
  
-  /* post recieve max msg size*/
+  /* post receive max msg size*/
  {
   int i;
   ib_recv_wr_t      *bad_wr_recv;
-  //recieve
+  //receive
   ctx->rwr.wr_id      = PINGPONG_RECV_WRID;
   ctx->rwr.ds_array = &ctx->recv_list;
   ctx->rwr.num_ds = 1;
@@ -663,7 +663,7 @@
    p_wc_free->p_next = NULL;
    PERF_DEBUG("rcnt %d\n",rcnt);
    PERF_DEBUG("scnt %d\n",scnt);
-   /*Server is polling on recieve first */
+   /*Server is polling on receive first */
    ++rcnt;
    if (ib_post_recv(qp, &rwr, &bad_wr_recv)) {
     fprintf(stderr, "Couldn't post recv: rcnt=%d\n",
@@ -698,12 +698,12 @@
    } while (ib_status == IB_NOT_FOUND);
 
    if (ib_status != IB_SUCCESS) {
-    fprintf(stderr, "Poll Recieve CQ failed %d\n", ib_status);
+    fprintf(stderr, "Poll Receive CQ failed %d\n", ib_status);
     return 12;
    }
    
    if (p_wc_done->status != IB_WCS_SUCCESS) {
-    fprintf(stderr, "Recieve Completion wth error at %s:\n",
+    fprintf(stderr, "Receive Completion wth error at %s:\n",
      user_param->servername ? "client" : "server");
     fprintf(stderr, "Failed status %d: wr_id %d\n",
      wc.status, (int) wc.wr_id);
@@ -756,12 +756,12 @@
    } while (ib_status == IB_NOT_FOUND);
 
    if (ib_status != IB_SUCCESS) {
-    fprintf(stderr, "Poll Recieve CQ failed %d\n", ib_status);
+    fprintf(stderr, "Poll Receive CQ failed %d\n", ib_status);
     return 12;
    }
    
    if (wc.status != IB_WCS_SUCCESS) {
-    fprintf(stderr, "Recieve Completion wth error at %s:\n",
+    fprintf(stderr, "Receive Completion wth error at %s:\n",
      user_param->servername ? "client" : "server");
     fprintf(stderr, "Failed status %d: wr_id %d\n",
      wc.status, (int) wc.wr_id);
Index: Q:/projinf4/trunk/tools/perftests/user/read_bw/read_bw.c
===================================================================
--- Q:/projinf4/trunk/tools/perftests/user/read_bw/read_bw.c (revision
3654)
+++ Q:/projinf4/trunk/tools/perftests/user/read_bw/read_bw.c (revision
3655)
@@ -564,7 +564,7 @@
    } while (ib_status == IB_SUCCESS);
 
    if (ib_status != IB_NOT_FOUND) {
-    fprintf(stderr, "Poll Recieve CQ failed %d\n", ib_status);
+    fprintf(stderr, "Poll Receive CQ failed %d\n", ib_status);
     return 12;
    }
 
Index: Q:/projinf4/trunk/ulp/ipoib/kernel/ipoib_port.c
===================================================================
--- Q:/projinf4/trunk/ulp/ipoib/kernel/ipoib_port.c (revision 3654)
+++ Q:/projinf4/trunk/ulp/ipoib/kernel/ipoib_port.c (revision 3655)
@@ -4675,7 +4675,7 @@
 {
  IPOIB_ENTER( IPOIB_DBG_ENDPT );
 
- /* This function must be called from the recieve path */
+ /* This function must be called from the receive path */
  CL_ASSERT(p_port->endpt_rdr > 0);
 
  cl_obj_lock( &p_port->obj );
Index: Q:/projinf4/trunk/tests/perftest/send_bw/send_bw.c
===================================================================
--- Q:/projinf4/trunk/tests/perftest/send_bw/send_bw.c (revision 3654)
+++ Q:/projinf4/trunk/tests/perftest/send_bw/send_bw.c (revision 3655)
@@ -578,11 +578,11 @@
    return 1;
   }
  }
  /* post recieve max msg size*/
  {
   int i;
   struct ibv_recv_wr      *bad_wr_recv;
-  //recieve
+  //receive
   ctx->rwr.wr_id      = PINGPONG_RECV_WRID;
   ctx->rwr.sg_list    = &ctx->recv_list;
   ctx->rwr.num_sge    = 1;
@@ -685,9 +685,9 @@
   * Important note :
   * In case of UD/UC this is NOT the way to measure
   * BW sicen we are running with loop on the send side
   * while we should run on the recieve side or enable retry in SW
   * Since the sender may be faster than the reciver than although
   * we had posted recieve it is not enough and might end this will
   * result in deadlock of test since both sides are stuck on poll cq
   * In this test i do not solve this for the general test ,need to send
   * seperate test for UC/UD but in case the tx_depth is ~1/3 from the
@@ -821,7 +821,7 @@
   while (rcnt < user_param->iters) {
    int ne;
    struct ibv_wc wc;
    /*Server is polling on recieve first */
    if (user_param->use_event) {
     struct ibv_cq *ev_cq;
     void          *ev_ctx;
@@ -862,7 +862,7 @@
    } while (ne > 0 );
 
    if (ne < 0) {
-    fprintf(stderr, "Poll Recieve CQ failed %d\n", ne);
+    fprintf(stderr, "Poll Receive CQ failed %d\n", ne);
     return 12;
    }
   }
@@ -1214,7 +1214,7 @@
  ctx->wr.opcode     = IBV_WR_SEND;
  ctx->wr.next       = NULL;
 
- /* recieve */
+ /* receive */
  ctx->rwr.wr_id      = PINGPONG_RECV_WRID;
  ctx->rwr.sg_list    = &ctx->recv_list;
  ctx->rwr.num_sge    = 1;
@@ -578,11 +578,11 @@
   }
  }
- /* post recieve max msg size*/
+ /* post receive max msg size*/
  {
   int i;
@@ -685,9 +685,9 @@
   * In case of UD/UC this is NOT the way to measure
   * BW sicen we are running with loop on the send side
-  * while we should run on the recieve side or enable retry in SW
+  * while we should run on the receive side or enable retry in SW
   * Since the sender may be faster than the reciver than although
@@ -685,9 +685,9 @@
   * Since the sender may be faster than the reciver than although
-  * we had posted recieve it is not enough and might end this will
+  * we had posted receive it is not enough and might end this will
   * result in deadlock of test since both sides are stuck on poll cq
   * In this test i do not solve this for the general test ,need to send
@@ -821,7 +821,7 @@
    int ne;
    struct ibv_wc wc;
-   /*Server is polling on recieve first */
+   /*Server is polling on receive first */
    if (user_param->use_event) {
     struct ibv_cq *ev_cq;
Index: Q:/projinf4/trunk/tests/perftest/send_lat/send_lat.c
===================================================================
--- Q:/projinf4/trunk/tests/perftest/send_lat/send_lat.c (revision 3654)
+++ Q:/projinf4/trunk/tests/perftest/send_lat/send_lat.c (revision 3655)
@@ -388,7 +388,7 @@
  }
  ctx->rcq = ibv_create_cq(ctx->context, tx_depth, NULL, ctx->channel,
0);
  if (!ctx->rcq) {
-  fprintf(stderr, "Couldn't create Recieve CQ\n");
+  fprintf(stderr, "Couldn't create Receive CQ\n");
   return NULL;
  }
  {
@@ -476,7 +476,7 @@
  ctx->wr.num_sge    = 1;
  ctx->wr.opcode     = IBV_WR_SEND;
  ctx->wr.next       = NULL;
- //recieve
+ //receive
  ctx->rwr.wr_id      = PINGPONG_RECV_WRID;
  ctx->rwr.sg_list    = &ctx->recv_list;
  ctx->rwr.num_sge    = 1;
@@ -602,7 +602,7 @@
    return 1;
   }
  }
  /* post recieve max msg size*/
  {
   int i;
   struct ibv_recv_wr      *bad_wr_recv;
@@ -854,7 +854,7 @@
   if (rcnt < iters && !(scnt < 1 && user_param->servername)) {
    int ne;
    struct ibv_wc wc;
    /*Server is polling on recieve first */
    ++rcnt;
    if (ibv_post_recv(qp, &rwr, &bad_wr_recv)) {
     fprintf(stderr, "Couldn't post recv: rcnt=%d\n",
@@ -885,11 +885,11 @@
    } while (!user_param->use_event && ne < 1);
 
    if (ne < 0) {
-    fprintf(stderr, "Poll Recieve CQ failed %d\n", ne);
+    fprintf(stderr, "Poll Receive CQ failed %d\n", ne);
     return 12;
    }
    if (wc.status != IBV_WC_SUCCESS) {
-    fprintf(stderr, "Recieve Completion wth error at %s:\n",
+    fprintf(stderr, "Receive Completion wth error at %s:\n",
      user_param->servername ? "client" : "server");
     fprintf(stderr, "Failed status %d: wr_id %d\n",
      wc.status, (int) wc.wr_id);

-------------- next part --------------
@@ -602,7 +602,7 @@
   }
  }
- /* post recieve max msg size*/
+ /* post receive max msg size*/
  {
   int i;
@@ -854,7 +854,7 @@
    int ne;
    struct ibv_wc wc;
-   /*Server is polling on recieve first */
+   /*Server is polling on receive first */
    ++rcnt;
    if (ibv_post_recv(qp, &rwr, &bad_wr_recv)) {
An HTML attachment was scrubbed...
URL: <http://lists.openfabrics.org/pipermail/ofw/attachments/20081221/49857a31/attachment.html>


More information about the ofw mailing list